@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2023 Free Software Foundation, Inc.
+ * Copyright (c) 2017-2024 Free Software Foundation, Inc.
  *
  * This file is part of libwget.
  *
@@ -151,7 +151,10 @@ struct addrinfo *wget_dns_cache_get(wget_dns_cache *cache, const char *host, uin
 
 		if (entryp) {
 			// DNS cache entry found
-			debug_printf("Found dns cache entry %s:%d\n", entryp->host, entryp->port);
+			if (wget_ip_is_family(entryp->host, WGET_NET_FAMILY_IPV6))
+				debug_printf("Found dns cache entry [%s]:%d\n", entryp->host, entryp->port);
+			else
+				debug_printf("Found dns cache entry %s:%d\n", entryp->host, entryp->port);
 			return entryp->addrinfo;
 		}
 	}
